Default mapping from AnnData obsm keys to Seurat reduction (name, key) pairs
Source:R/attach_reductions_seurat.R
default_reduction_map.RdProvides the canonical Seurat naming for the obsm keys conventionally produced by scanpy. Users who want extra mappings should pass a list with the same shape into `attach_reductions_seurat()` (or its callers).